************
User Guide 
************

llvmpy provides Python bindings for LLVM. This document explains how
you can setup and use it. A working knowledge of Python and a basic idea
of LLVM is assumed.

.. toctree::
   :maxdepth: 1

   getting_started.rst
   llvm_concepts.rst
   llvmpy_package.rst
   


